@@ -10,7 +10,7 @@ Image::Magick::Safer - Wrap Image::Magick Read method to check magic bytes
 
 =head1 VERSION
 
-0.04
+0.05
 
 =head1 SYNOPSIS
 
@@ -59,6 +59,9 @@ The default MIME types considered unsafe are as follows:
 	application/x-z
 	application/z
 
+Leading pipes are also considered unsafe, as well as any reference to files
+that cannot be found.
+
 Note that i make B<NO GUARANTEE> that this will fix and/or protect you from
 exploits, it's just another safety check. You should update to the latest
 version of ImageMagick to protect yourself against potential exploits.
@@ -81,7 +84,7 @@ use warnings;
 use parent 'Image::Magick';
 use File::LibMagic;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # imagemagick can automatically uncompress archive files so there's another
 # attack vector in having an exploit image zipped up, so just checking for
@@ -109,6 +112,9 @@ sub Read {
 
 	foreach my $image ( @images ) {
 
+		return "cannot open $image (file not found)" if ! -f $image;
+		return "cannot open $image (leading pipe)" if $image =~ /\s*\|/;
+
 		# info has:
 		#     mime_with_encoding
 		#     description
